=======
Skidder
=======


Overview
--------

Skidder is a python logging library. Note that this is very **alpha** level software and things may change dramatically as the project evolves.

In real life a skidder_ is any type of heavy vehicle used in a logging operation for pulling cut trees out of a forest.


Getting Started
---------------

pip install skidder


Running Tests
-------------

TBD


License
-------

The project is licensed under the MIT License - see the LICENSE.md_ file for details.

.. _license.md: /LICENSE.txt
.. _skidder: https://en.wikipedia.org/wiki/Skidder
